#
# spec file for package sblim-cmpi-devel
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sblim-cmpi-devel
Version:        2.0.3
Release:        9.1
URL:            http://sblim.sf.net/
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  libtool
Provides:       cmpi-devel
Conflicts:      tog-pegasus < 2.11
Source0:        http://prdownloads.sourceforge.net/sblim/%{name}-%{version}.tar.bz2
Source1:        Doxyfile
%if 0%{?mandriva_version}
Patch0:         mandriva-docdir.patch
%else
Patch0:         opensuse-docdir.patch
%endif
Patch1:         old-gcc.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Summary:        SBLIM CMPI Provider Development Support
License:        EPL-1.0
Group:          Development/Libraries/C and C++

%description
This packages provides the C and C++ CMPI header files needed by
provider developers and can be used standalone. If used for C++
provider development it is also necessary to have tog-pegasus-devel
installed.

%package -n sblim-cmpi-c++-devel
Summary:        SBLIM CMPI Provider Development Support
Group:          Development/Libraries/C and C++
Requires:       %{name}
Requires:       libcmpiCppImpl0
Conflicts:      tog-pegasus

%description -n sblim-cmpi-c++-devel
This packages provides the C and C++ CMPI header files needed by
provider developers and can be used standalone. If used for C++
provider development it is also necessary to have tog-pegasus-devel
installed.

%package -n libcmpiCppImpl0
Summary:        SBLIM CMPI Provider Development Support
Group:          Development/Libraries/C and C++
Conflicts:      tog-pegasus

%description -n libcmpiCppImpl0
This packages provides the C and C++ CMPI header files needed by
provider developers and can be used standalone. If used for C++
provider development it is also necessary to have tog-pegasus-devel
installed.


%if 0%{?fedora_version} || 0%{?centos_version} || 0%{?rhel_version} || 0%{?fedora} || 0%{?rhel}
%define cmpi_docdir %_docdir/%{name}-%{version}
%else
%define cmpi_docdir %_docdir/%{name}
%endif

%prep
%setup -T -b 0 -n %{name}-%{version}
%if 0%{?suse_version} || 0%{?mandriva_version}
# adapt docdir
%patch0
%endif
%patch1 -p1

cp %{_sourcedir}/Doxyfile %{_builddir}/%{name}-%{version}/
mkdir %{_builddir}/%{name}-%{version}/autodocs

%build
autoreconf --verbose --force --install
%configure
make %{?_smp_mflags}
doxygen Doxyfile

%install
make DESTDIR=$RPM_BUILD_ROOT install
rm -f $RPM_BUILD_ROOT/%{_libdir}/libcmpiCppImpl.a
rm -f $RPM_BUILD_ROOT/%{_libdir}/libcmpiCppImpl.la
mkdir -p $RPM_BUILD_ROOT/%{cmpi_docdir}
cp -r autodocs/ $RPM_BUILD_ROOT/%{cmpi_docdir}

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc %{cmpi_docdir}
%dir %{_includedir}/cmpi
%{_includedir}/cmpi/[a-z]*

%files -n sblim-cmpi-c++-devel
%defattr(-,root,root)
%{_libdir}/libcmpiCppImpl.so
%dir %{_includedir}/cmpi
%{_includedir}/cmpi/[A-Z]*

%files -n libcmpiCppImpl0
%defattr(-,root,root)
%{_libdir}/libcmpiCppImpl.so.0*

%post -n libcmpiCppImpl0 -p /sbin/ldconfig

%postun -n libcmpiCppImpl0 -p /sbin/ldconfig

%changelog
* Tue Nov  7 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Mon Apr  1 2013 kkaempf@suse.com
- fix includes to compile with older gcc versions
* Wed Aug  1 2012 kkaempf@suse.com
- Update to 2.0.3
  Bugs Fixed:
  - 3531598 several CmpiObjectPath methods leak memory
  - 3531599 replace CMGetCharPtr with CMGetCharsPtr
  - 3531597 returnData with char type fails
  - 3531596 CmpiData uses wrong union for unsigned data
  New Features:
  - 3531601 add CmpiString constructor for char data
  - 3531603 no way to determine internal type of CmpiData
    (add getType function)
* Tue Feb 28 2012 kkaempf@suse.com
- Conflict only with pre-2.11 versions of tog-pegasus
* Wed Dec 14 2011 coolo@suse.com
- fix license to be in spdx.org format
* Sun Nov 27 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Thu Jul 14 2011 kkaempf@novell.com
- update to 2.0.2
  Bugfix release:
  * 2688794 Fixed typo in cmpi/cmpidt.h
  * 2817255 CmpiData constructor for CmpiString argument produce garbage
  * 3005546 cmpi thread key typed defined wrong on s390x
* Wed Jan 13 2010 kkaempf@novell.com
- Fix _docdir for Mandriva
* Wed Jan 13 2010 kkaempf@novell.com
- Fix _docdir for Fedora/RHEL
* Thu Nov 19 2009 kukuk@suse.de
- Fix filelist (wrong usage of %%dir)
* Wed Nov 18 2009 ro@suse.de
- fix filelist (missing defattr)
* Mon Nov  9 2009 bwhiteley@suse.de
- Split c++ wrapper headers and devel lib into separate package.
  (fate#306414)
* Wed Oct 14 2009 mhrusecky@suse.cz
- sending current development version to SLE11 SP1 (fate#307089)
* Mon May 11 2009 mhrusecky@suse.cz
- fixed typo in cmpidt.h
- adding conflict with tog-pegasus to spec file
* Fri May  8 2009 mc@suse.de
- fix CmpiString
- add Doxygen file and create autodocs
- build and package c++ wrapper library
* Tue Mar 10 2009 ro@suse.de
- fix filelist
* Fri Mar  6 2009 kkaempf@suse.de
- Update to 2.0.1
- Don't run ldconfig
- Fix docdir
* Sun May 18 2008 aj@suse.de
- Do not clean build root in install section.
* Fri May  2 2008 bwhiteley@suse.de
- First checkin
